@@ -102,7 +102,7 @@ int python_u_tld_key = -1;
 int python_qobj_key = -1;
 
 static sig_vec_t sig_vec = {
-#ifndef Q_WINDOWS
+#ifndef _Q_WINDOWS
     SIGSEGV, SIGBUS
 #endif
 };
@@ -258,7 +258,7 @@ static QoreStringNode* python_module_init_intern(bool repeat) {
     }
 
     if (!repeat) {
-#ifndef Q_WINDOWS
+#ifndef _Q_WINDOWS
         sig_vec_t new_sig_vec;
         for (int sig : sig_vec) {
             QoreStringNode *err = qore_reassign_signal(sig, QORE_PYTHON_MODULE_NAME);
@@ -547,20 +547,17 @@ QorePythonGilHelper::QorePythonGilHelper(PyThreadState* new_thread_state)
     : new_thread_state(new_thread_state), state(_qore_PyRuntimeGILState_GetThreadState()),
         t_state(PyGILState_GetThisThreadState()),
         release_gil(!_qore_has_gil(t_state, new_thread_state)) {
-    assert(new_thread_state);
     //printd(5, "QorePythonGilHelper::QorePythonGilHelper() %llx acquire: %d state: %llx t_state: %llx\n",
     //    new_thread_state, release_gil, state, t_state);
+    assert(new_thread_state);
     if (release_gil) {
         PyEval_AcquireThread(new_thread_state);
         assert(PyThreadState_Get() == new_thread_state);
     } else {
         assert(t_state == _qore_PyCeval_GetThreadState());
-        if (t_state == new_thread_state) {
-            do_nothing = true;
-            //printd(5, "QorePythonGilHelper::QorePythonGilHelper() %llx noop\n", new_thread_state);
-            return;
-        }
     }
+    // NOTE: even if the current thread state is equal to the new one, we still need to set all thread states in all
+    // locations
 
     ++new_thread_state->gilstate_counter;
     PyThreadState_Swap(new_thread_state);
@@ -573,9 +570,6 @@ QorePythonGilHelper::QorePythonGilHelper(PyThreadState* new_thread_state)
 
 QorePythonGilHelper::~QorePythonGilHelper() {
     assert(_qore_has_gil());
-    if (do_nothing) {
-        return;
-    }
 
     --new_thread_state->gilstate_counter;
 
